==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/SciFigs/src/TextEditProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef TEXTEDITPROPERTIES_H
#define TEXTEDITPROPERTIES_H

#include "ui_TextEditProperties.h"
#include "TextEdit.h"

namespace SciFigs {

class TextEditProperties : public PropertyWidget, private Ui::TextEditProperties
{
  Q_OBJECT
public:
  TextEditProperties(QWidget * parent=nullptr);

  enum Properties {TextAsData, Text, Font, AdjustBox};
private:
  virtual PropertyValue::WidgetType determineCustomWidgetType(int pid, QWidget * w, QWidget * label);
  virtual bool connectCustomWidget(PropertyValue & p);
  virtual bool setCustomWidget(PropertyValue & p);
  virtual QVariant customWidgetValue(PropertyValue & p);
private slots:
  void on_fontBut_clicked();
};

} // namespace SciFigs

#endif // TEXTEDITPROPERTIES_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/SciFigs/src/TextEditProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef TEXTEDITPROPERTIES_H
#define TEXTEDITPROPERTIES_H

#include "ui_TextEditProperties.h"
#include "TextEdit.h"

namespace SciFigs {

class TextEditProperties : public PropertyWidget, private Ui::TextEditProperties
{
  Q_OBJECT
public:
  TextEditProperties(QWidget * parent=nullptr);

  enum Properties {TextAsData, Text, Font, AdjustBox, Color};
private:
  virtual PropertyValue::WidgetType determineCustomWidgetType(int pid, QWidget * w, QWidget * label);
  virtual bool connectCustomWidget(PropertyValue & p);
  virtual bool setCustomWidget(PropertyValue & p);
  virtual QVariant customWidgetValue(PropertyValue & p);
private slots:
  void on_fontBut_clicked();
};

} // namespace SciFigs

#endif // TEXTEDITPROPERTIES_H
